# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerKnowledgeBeacon(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beacon': 'int',
        'name': 'str',
        'url': 'str',
        'description': 'str',
        'contact': 'str',
        'wraps': 'str',
        'repo': 'str'
    }

    attribute_map = {
        'beacon': 'beacon',
        'name': 'name',
        'url': 'url',
        'description': 'description',
        'contact': 'contact',
        'wraps': 'wraps',
        'repo': 'repo'
    }

    def __init__(self, beacon=None, name=None, url=None, description=None, contact=None, wraps=None, repo=None):  # noqa: E501
        """ServerKnowledgeBeacon - a model defined in Swagger"""  # noqa: E501

        self._beacon = None
        self._name = None
        self._url = None
        self._description = None
        self._contact = None
        self._wraps = None
        self._repo = None
        self.discriminator = None

        if beacon is not None:
            self.beacon = beacon
        if name is not None:
            self.name = name
        if url is not None:
            self.url = url
        if description is not None:
            self.description = description
        if contact is not None:
            self.contact = contact
        if wraps is not None:
            self.wraps = wraps
        if repo is not None:
            self.repo = repo

    @property
    def beacon(self):
        """Gets the beacon of this ServerKnowledgeBeacon.  # noqa: E501

        aggregator assigned beacon index identifier   # noqa: E501

        :return: The beacon of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerKnowledgeBeacon.

        aggregator assigned beacon index identifier   # noqa: E501

        :param beacon: The beacon of this ServerKnowledgeBeacon.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def name(self):
        """Gets the name of this ServerKnowledgeBeacon.  # noqa: E501

        beacon name   # noqa: E501

        :return: The name of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServerKnowledgeBeacon.

        beacon name   # noqa: E501

        :param name: The name of this ServerKnowledgeBeacon.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def url(self):
        """Gets the url of this ServerKnowledgeBeacon.  # noqa: E501

        URL used to execute API calls on the beacon   # noqa: E501

        :return: The url of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ServerKnowledgeBeacon.

        URL used to execute API calls on the beacon   # noqa: E501

        :param url: The url of this ServerKnowledgeBeacon.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def description(self):
        """Gets the description of this ServerKnowledgeBeacon.  # noqa: E501

        beacon description   # noqa: E501

        :return: The description of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServerKnowledgeBeacon.

        beacon description   # noqa: E501

        :param description: The description of this ServerKnowledgeBeacon.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def contact(self):
        """Gets the contact of this ServerKnowledgeBeacon.  # noqa: E501

        name of the person responsible for this beacon   # noqa: E501

        :return: The contact of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this ServerKnowledgeBeacon.

        name of the person responsible for this beacon   # noqa: E501

        :param contact: The contact of this ServerKnowledgeBeacon.  # noqa: E501
        :type: str
        """

        self._contact = contact

    @property
    def wraps(self):
        """Gets the wraps of this ServerKnowledgeBeacon.  # noqa: E501

        URL of this beacon's data source   # noqa: E501

        :return: The wraps of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: str
        """
        return self._wraps

    @wraps.setter
    def wraps(self, wraps):
        """Sets the wraps of this ServerKnowledgeBeacon.

        URL of this beacon's data source   # noqa: E501

        :param wraps: The wraps of this ServerKnowledgeBeacon.  # noqa: E501
        :type: str
        """

        self._wraps = wraps

    @property
    def repo(self):
        """Gets the repo of this ServerKnowledgeBeacon.  # noqa: E501

        URL of this beacon's repository   # noqa: E501

        :return: The repo of this ServerKnowledgeBeacon.  # noqa: E501
        :rtype: str
        """
        return self._repo

    @repo.setter
    def repo(self, repo):
        """Sets the repo of this ServerKnowledgeBeacon.

        URL of this beacon's repository   # noqa: E501

        :param repo: The repo of this ServerKnowledgeBeacon.  # noqa: E501
        :type: str
        """

        self._repo = repo

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerKnowledgeBeacon):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerStatementCitation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'uri': 'str',
        'name': 'str',
        'evidence_type': 'str',
        'date': 'str'
    }

    attribute_map = {
        'id': 'id',
        'uri': 'uri',
        'name': 'name',
        'evidence_type': 'evidence_type',
        'date': 'date'
    }

    def __init__(self, id=None, uri=None, name=None, evidence_type=None, date=None):  # noqa: E501
        """ServerStatementCitation - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._uri = None
        self._name = None
        self._evidence_type = None
        self._date = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if uri is not None:
            self.uri = uri
        if name is not None:
            self.name = name
        if evidence_type is not None:
            self.evidence_type = evidence_type
        if date is not None:
            self.date = date

    @property
    def id(self):
        """Gets the id of this ServerStatementCitation.  # noqa: E501

        CURIE-encoded identifier to a citation to evidence supporting the given statement (e.g. PMID of a pubmed abstract)   # noqa: E501

        :return: The id of this ServerStatementCitation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerStatementCitation.

        CURIE-encoded identifier to a citation to evidence supporting the given statement (e.g. PMID of a pubmed abstract)   # noqa: E501

        :param id: The id of this ServerStatementCitation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def uri(self):
        """Gets the uri of this ServerStatementCitation.  # noqa: E501

        (optional) expansion of the citation CURIE   # noqa: E501

        :return: The uri of this ServerStatementCitation.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ServerStatementCitation.

        (optional) expansion of the citation CURIE   # noqa: E501

        :param uri: The uri of this ServerStatementCitation.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def name(self):
        """Gets the name of this ServerStatementCitation.  # noqa: E501

        canonical human readable and searchable name of the citation (i.e. publication title, comment, etc.)   # noqa: E501

        :return: The name of this ServerStatementCitation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServerStatementCitation.

        canonical human readable and searchable name of the citation (i.e. publication title, comment, etc.)   # noqa: E501

        :param name: The name of this ServerStatementCitation.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def evidence_type(self):
        """Gets the evidence_type of this ServerStatementCitation.  # noqa: E501

        class of evidence supporting the statement made in an edge - typically a class from the ECO ontology (e.g. ECO:0000220 'sequencing assay evidence', see [Evidence Ontology](http://purl.obolibrary.org/obo/eco.owl)   # noqa: E501

        :return: The evidence_type of this ServerStatementCitation.  # noqa: E501
        :rtype: str
        """
        return self._evidence_type

    @evidence_type.setter
    def evidence_type(self, evidence_type):
        """Sets the evidence_type of this ServerStatementCitation.

        class of evidence supporting the statement made in an edge - typically a class from the ECO ontology (e.g. ECO:0000220 'sequencing assay evidence', see [Evidence Ontology](http://purl.obolibrary.org/obo/eco.owl)   # noqa: E501

        :param evidence_type: The evidence_type of this ServerStatementCitation.  # noqa: E501
        :type: str
        """

        self._evidence_type = evidence_type

    @property
    def date(self):
        """Gets the date of this ServerStatementCitation.  # noqa: E501

        publication date of annotation (generally of format 'yyyy-mm-dd')   # noqa: E501

        :return: The date of this ServerStatementCitation.  # noqa: E501
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this ServerStatementCitation.

        publication date of annotation (generally of format 'yyyy-mm-dd')   # noqa: E501

        :param date: The date of this ServerStatementCitation.  # noqa: E501
        :type: str
        """

        self._date = date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementCitation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_statement import ServerStatement  # noqa: F401,E501


class ServerStatementsQueryResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_id': 'str',
        'beacons': 'list[int]',
        'page_number': 'int',
        'page_size': 'int',
        'results': 'list[ServerStatement]'
    }

    attribute_map = {
        'query_id': 'queryId',
        'beacons': 'beacons',
        'page_number': 'pageNumber',
        'page_size': 'pageSize',
        'results': 'results'
    }

    def __init__(self, query_id=None, beacons=None, page_number=None, page_size=None, results=None):  # noqa: E501
        """ServerStatementsQueryResult - a model defined in Swagger"""  # noqa: E501

        self._query_id = None
        self._beacons = None
        self._page_number = None
        self._page_size = None
        self._results = None
        self.discriminator = None

        if query_id is not None:
            self.query_id = query_id
        if beacons is not None:
            self.beacons = beacons
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if results is not None:
            self.results = results

    @property
    def query_id(self):
        """Gets the query_id of this ServerStatementsQueryResult.  # noqa: E501

        session identifier of the query returning the results   # noqa: E501

        :return: The query_id of this ServerStatementsQueryResult.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this ServerStatementsQueryResult.

        session identifier of the query returning the results   # noqa: E501

        :param query_id: The query_id of this ServerStatementsQueryResult.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    @property
    def beacons(self):
        """Gets the beacons of this ServerStatementsQueryResult.  # noqa: E501


        :return: The beacons of this ServerStatementsQueryResult.  # noqa: E501
        :rtype: list[int]
        """
        return self._beacons

    @beacons.setter
    def beacons(self, beacons):
        """Sets the beacons of this ServerStatementsQueryResult.


        :param beacons: The beacons of this ServerStatementsQueryResult.  # noqa: E501
        :type: list[int]
        """

        self._beacons = beacons

    @property
    def page_number(self):
        """Gets the page_number of this ServerStatementsQueryResult.  # noqa: E501

        'pageNumber' string parameter to API call, echoed back   # noqa: E501

        :return: The page_number of this ServerStatementsQueryResult.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this ServerStatementsQueryResult.

        'pageNumber' string parameter to API call, echoed back   # noqa: E501

        :param page_number: The page_number of this ServerStatementsQueryResult.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this ServerStatementsQueryResult.  # noqa: E501

        'pageSize' string parameter to API call, echoed back   # noqa: E501

        :return: The page_size of this ServerStatementsQueryResult.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this ServerStatementsQueryResult.

        'pageSize' string parameter to API call, echoed back   # noqa: E501

        :param page_size: The page_size of this ServerStatementsQueryResult.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def results(self):
        """Gets the results of this ServerStatementsQueryResult.  # noqa: E501


        :return: The results of this ServerStatementsQueryResult.  # noqa: E501
        :rtype: list[ServerStatement]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this ServerStatementsQueryResult.


        :param results: The results of this ServerStatementsQueryResult.  # noqa: E501
        :type: list[ServerStatement]
        """

        self._results = results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementsQueryResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from kba import ConceptsApi
from kba import StatementsApi

from kba.api_client import ApiClient
from kba.configuration import Configuration

from typing import List

import click, time, itertools

class Query(object):
    def __init__(self, query, api, status_fn, get_fn):
        self.query = query
        self.api = api
        self.status_fn = status_fn
        self.get_fn = get_fn

    @property
    def id(self):
        return self.query.query_id

    @property
    def keywords(self):
        return self.query.keywords

    @property
    def categories(self):
        return self.query.categories

    def status(self, beacons:list=None):
        if beacons is not None:
            return self.status_fn(self.id, beacons=beacons)
        else:
            return self.status_fn(self.id)

    def get(self):
        return self.get_fn(self.id)

    def wait(self, seconds=3):
        unfinished = [s.beacon for s in self.status().status]

        while unfinished != []:

            with click.progressbar(itertools.repeat(None), label='Waiting for beacons to return...') as bar:
                for _ in bar:
                    for status in self.status().status:
                        is_ready = status.discovered is not None or status.count is not None
                        if is_ready and status.beacon in unfinished:
                            unfinished.remove(status.beacon)
                            break
                    else:
                        time.sleep(seconds)
                        continue
                    break

            if status.discovered is not None:
                with click.progressbar(range(status.discovered), label='Processing beacon {}'.format(status.beacon)) as bar:
                    prev_processed = 0
                    for _ in bar:
                        new_status = next(s for s in self.status().status if s.beacon == status.beacon)
                        bar.update(new_status.processed - prev_processed)
                        prev_processed = new_status.processed

                        if new_status.processed != new_status.discovered:
                            time.sleep(seconds)

        data = self.get()

        if data == []:
            click.echo('No records discovered for {}'.format(self.id))
        else:
            return data






class AggregatorApi(object):
    def __init__(self, host=None):
        self.concepts_api = ConceptsApi()
        self.statements_api = StatementsApi()

        if host is not None:
            self.concepts_api.api_client.configuration.host = host
            self.statements_api.api_client.configuration.host = host

    def build_concept_query(self, keywords:List[str], categories:List[str]=None, beacons:List[int]=None):
        kwargs = {}

        if categories is not None:
            kwargs['categories'] = categories

        if beacons is not None:
            kwargs['beacons'] = beacons

        q = self.concepts_api.post_concepts_query(keywords=keywords, **kwargs)

        return Query(
            q,
            self.concepts_api,
            self.concepts_api.get_concepts_query_status,
            self.concepts_api.get_concepts,
        )



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerConcept(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'clique': 'str',
        'name': 'str',
        'categories': 'list[str]'
    }

    attribute_map = {
        'clique': 'clique',
        'name': 'name',
        'categories': 'categories'
    }

    def __init__(self, clique=None, name=None, categories=None):  # noqa: E501
        """ServerConcept - a model defined in Swagger"""  # noqa: E501

        self._clique = None
        self._name = None
        self._categories = None
        self.discriminator = None

        if clique is not None:
            self.clique = clique
        if name is not None:
            self.name = name
        if categories is not None:
            self.categories = categories

    @property
    def clique(self):
        """Gets the clique of this ServerConcept.  # noqa: E501

        CURIE identifying the inferred equivalent concept clique to which the concept belongs. This is assigned by an identifier precedence heuristic by the beacon-aggregator   # noqa: E501

        :return: The clique of this ServerConcept.  # noqa: E501
        :rtype: str
        """
        return self._clique

    @clique.setter
    def clique(self, clique):
        """Sets the clique of this ServerConcept.

        CURIE identifying the inferred equivalent concept clique to which the concept belongs. This is assigned by an identifier precedence heuristic by the beacon-aggregator   # noqa: E501

        :param clique: The clique of this ServerConcept.  # noqa: E501
        :type: str
        """

        self._clique = clique

    @property
    def name(self):
        """Gets the name of this ServerConcept.  # noqa: E501

        Canonical human readable name of the concept   # noqa: E501

        :return: The name of this ServerConcept.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServerConcept.

        Canonical human readable name of the concept   # noqa: E501

        :param name: The name of this ServerConcept.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def categories(self):
        """Gets the categories of this ServerConcept.  # noqa: E501

        Concept categories associated with the given concept ((see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of categories).   # noqa: E501

        :return: The categories of this ServerConcept.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ServerConcept.

        Concept categories associated with the given concept ((see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of categories).   # noqa: E501

        :param categories: The categories of this ServerConcept.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerConcept):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerStatementsQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_id': 'str',
        'source': 'str',
        'relations': 'list[str]',
        'target': 'str',
        'keywords': 'list[str]',
        'categories': 'list[str]'
    }

    attribute_map = {
        'query_id': 'queryId',
        'source': 'source',
        'relations': 'relations',
        'target': 'target',
        'keywords': 'keywords',
        'categories': 'categories'
    }

    def __init__(self, query_id=None, source=None, relations=None, target=None, keywords=None, categories=None):  # noqa: E501
        """ServerStatementsQuery - a model defined in Swagger"""  # noqa: E501

        self._query_id = None
        self._source = None
        self._relations = None
        self._target = None
        self._keywords = None
        self._categories = None
        self.discriminator = None

        if query_id is not None:
            self.query_id = query_id
        if source is not None:
            self.source = source
        if relations is not None:
            self.relations = relations
        if target is not None:
            self.target = target
        if keywords is not None:
            self.keywords = keywords
        if categories is not None:
            self.categories = categories

    @property
    def query_id(self):
        """Gets the query_id of this ServerStatementsQuery.  # noqa: E501

        session identifier of initiated query   # noqa: E501

        :return: The query_id of this ServerStatementsQuery.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this ServerStatementsQuery.

        session identifier of initiated query   # noqa: E501

        :param query_id: The query_id of this ServerStatementsQuery.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    @property
    def source(self):
        """Gets the source of this ServerStatementsQuery.  # noqa: E501

        'source' string parameter to call, echoed back   # noqa: E501

        :return: The source of this ServerStatementsQuery.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this ServerStatementsQuery.

        'source' string parameter to call, echoed back   # noqa: E501

        :param source: The source of this ServerStatementsQuery.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def relations(self):
        """Gets the relations of this ServerStatementsQuery.  # noqa: E501

        'relations' string parameter to call, echoed back   # noqa: E501

        :return: The relations of this ServerStatementsQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._relations

    @relations.setter
    def relations(self, relations):
        """Sets the relations of this ServerStatementsQuery.

        'relations' string parameter to call, echoed back   # noqa: E501

        :param relations: The relations of this ServerStatementsQuery.  # noqa: E501
        :type: list[str]
        """

        self._relations = relations

    @property
    def target(self):
        """Gets the target of this ServerStatementsQuery.  # noqa: E501

        'target' string parameter to call, echoed back   # noqa: E501

        :return: The target of this ServerStatementsQuery.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this ServerStatementsQuery.

        'target' string parameter to call, echoed back   # noqa: E501

        :param target: The target of this ServerStatementsQuery.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def keywords(self):
        """Gets the keywords of this ServerStatementsQuery.  # noqa: E501

        'keywords' string filter parameter to call, echoed back   # noqa: E501

        :return: The keywords of this ServerStatementsQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this ServerStatementsQuery.

        'keywords' string filter parameter to call, echoed back   # noqa: E501

        :param keywords: The keywords of this ServerStatementsQuery.  # noqa: E501
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def categories(self):
        """Gets the categories of this ServerStatementsQuery.  # noqa: E501

        'categories' string parameter to call, echoed back   # noqa: E501

        :return: The categories of this ServerStatementsQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ServerStatementsQuery.

        'categories' string parameter to call, echoed back   # noqa: E501

        :param categories: The categories of this ServerStatementsQuery.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementsQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "kba"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "urllib3 >= 1.15",
    "six >= 1.10",
    "certifi",
    "python-dateutil",
    "click",
    "progress",
]

setup(
    name=NAME,
    version=VERSION,
    description="Translator Knowledge Beacon Aggregator API",
    author_email="richard@starinformatics.com",
    url="",
    keywords=["Swagger", "Translator Knowledge Beacon Aggregator API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501
    """,
    scripts=['bin/kba_cli.py'],
    entry_points='''
        [console_scripts]
        kba=kba_cli:cli
    ''',
)



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kba
from kba.models.server_knowledge_map_statement import ServerKnowledgeMapStatement  # noqa: E501
from kba.rest import ApiException


class TestServerKnowledgeMapStatement(unittest.TestCase):
    """ServerKnowledgeMapStatement unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testServerKnowledgeMapStatement(self):
        """Test ServerKnowledgeMapStatement"""
        # FIXME: construct object with mandatory attributes with example values
        # model = kba.models.server_knowledge_map_statement.ServerKnowledgeMapStatement()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_beacon_predicate import ServerBeaconPredicate  # noqa: F401,E501


class ServerPredicatesByBeacon(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beacon': 'int',
        'predicates': 'list[ServerBeaconPredicate]'
    }

    attribute_map = {
        'beacon': 'beacon',
        'predicates': 'predicates'
    }

    def __init__(self, beacon=None, predicates=None):  # noqa: E501
        """ServerPredicatesByBeacon - a model defined in Swagger"""  # noqa: E501

        self._beacon = None
        self._predicates = None
        self.discriminator = None

        if beacon is not None:
            self.beacon = beacon
        if predicates is not None:
            self.predicates = predicates

    @property
    def beacon(self):
        """Gets the beacon of this ServerPredicatesByBeacon.  # noqa: E501

        aggregator index of the given beacon   # noqa: E501

        :return: The beacon of this ServerPredicatesByBeacon.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerPredicatesByBeacon.

        aggregator index of the given beacon   # noqa: E501

        :param beacon: The beacon of this ServerPredicatesByBeacon.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def predicates(self):
        """Gets the predicates of this ServerPredicatesByBeacon.  # noqa: E501


        :return: The predicates of this ServerPredicatesByBeacon.  # noqa: E501
        :rtype: list[ServerBeaconPredicate]
        """
        return self._predicates

    @predicates.setter
    def predicates(self, predicates):
        """Sets the predicates of this ServerPredicatesByBeacon.


        :param predicates: The predicates of this ServerPredicatesByBeacon.  # noqa: E501
        :type: list[ServerBeaconPredicate]
        """

        self._predicates = predicates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerPredicatesByBeacon):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kba
from kba.api.statements_api import StatementsApi  # noqa: E501
from kba.rest import ApiException


class TestStatementsApi(unittest.TestCase):
    """StatementsApi unit test stubs"""

    def setUp(self):
        self.api = kba.api.statements_api.StatementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_statement_details(self):
        """Test case for get_statement_details

        """
        pass

    def test_get_statements(self):
        """Test case for get_statements

        """
        pass

    def test_get_statements_query_status(self):
        """Test case for get_statements_query_status

        """
        pass

    def test_post_statements_query(self):
        """Test case for post_statements_query

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerKnowledgeMapObject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'prefixes': 'list[str]'
    }

    attribute_map = {
        'category': 'category',
        'prefixes': 'prefixes'
    }

    def __init__(self, category=None, prefixes=None):  # noqa: E501
        """ServerKnowledgeMapObject - a model defined in Swagger"""  # noqa: E501

        self._category = None
        self._prefixes = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if prefixes is not None:
            self.prefixes = prefixes

    @property
    def category(self):
        """Gets the category of this ServerKnowledgeMapObject.  # noqa: E501

        the human readable label of the concept category of a statement object   # noqa: E501

        :return: The category of this ServerKnowledgeMapObject.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ServerKnowledgeMapObject.

        the human readable label of the concept category of a statement object   # noqa: E501

        :param category: The category of this ServerKnowledgeMapObject.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def prefixes(self):
        """Gets the prefixes of this ServerKnowledgeMapObject.  # noqa: E501


        :return: The prefixes of this ServerKnowledgeMapObject.  # noqa: E501
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """Sets the prefixes of this ServerKnowledgeMapObject.


        :param prefixes: The prefixes of this ServerKnowledgeMapObject.  # noqa: E501
        :type: list[str]
        """

        self._prefixes = prefixes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerKnowledgeMapObject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kba.api_client import ApiClient


class MetadataApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_beacons(self, **kwargs):  # noqa: E501
        """get_beacons  # noqa: E501

        Get a list of all of the knowledge beacons that the aggregator can query   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_beacons(async=True)
        >>> result = thread.get()

        :param async bool
        :return: list[ServerKnowledgeBeacon]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_beacons_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_beacons_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_beacons_with_http_info(self, **kwargs):  # noqa: E501
        """get_beacons  # noqa: E501

        Get a list of all of the knowledge beacons that the aggregator can query   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_beacons_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :return: list[ServerKnowledgeBeacon]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beacons" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beacons', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ServerKnowledgeBeacon]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_concept_categories(self, **kwargs):  # noqa: E501
        """get_concept_categories  # noqa: E501

        Get a list of semantic categories and number of instances in each available knowledge beacon, including associated beacon-specific metadata   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concept_categories(async=True)
        >>> result = thread.get()

        :param async bool
        :param list[int] beacons: set of aggregator indices of beacons to constrain categories returned 
        :return: list[ServerConceptCategory]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_concept_categories_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_concept_categories_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_concept_categories_with_http_info(self, **kwargs):  # noqa: E501
        """get_concept_categories  # noqa: E501

        Get a list of semantic categories and number of instances in each available knowledge beacon, including associated beacon-specific metadata   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concept_categories_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param list[int] beacons: set of aggregator indices of beacons to constrain categories returned 
        :return: list[ServerConceptCategory]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_concept_categories" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/categories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ServerConceptCategory]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_error_log(self, query_id, **kwargs):  # noqa: E501
        """get_error_log  # noqa: E501

        Get a log of the system errors associated with a specified query   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_error_log(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: query identifier returned from a POSTed query  (required)
        :return: list[ServerLogEntry]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_error_log_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_error_log_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_error_log_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_error_log  # noqa: E501

        Get a log of the system errors associated with a specified query   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_error_log_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: query identifier returned from a POSTed query  (required)
        :return: list[ServerLogEntry]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_error_log" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_error_log`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'query_id' in params:
            query_params.append(('queryId', params['query_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/errorlog', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ServerLogEntry]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_knowledge_map(self, **kwargs):  # noqa: E501
        """get_knowledge_map  # noqa: E501

        Get a high level knowledge map of the all the beacons specified by triplets of subject concept category, relationship predicate and concept object category   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_knowledge_map(async=True)
        >>> result = thread.get()

        :param async bool
        :param list[int] beacons: set of aggregator indices of beacons constraining knowledge maps returned 
        :return: list[ServerKnowledgeMap]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_knowledge_map_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_knowledge_map_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_knowledge_map_with_http_info(self, **kwargs):  # noqa: E501
        """get_knowledge_map  # noqa: E501

        Get a high level knowledge map of the all the beacons specified by triplets of subject concept category, relationship predicate and concept object category   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_knowledge_map_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param list[int] beacons: set of aggregator indices of beacons constraining knowledge maps returned 
        :return: list[ServerKnowledgeMap]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_knowledge_map" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/kmap', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ServerKnowledgeMap]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_predicates(self, **kwargs):  # noqa: E501
        """get_predicates  # noqa: E501

        Get a list of predicates used in statements issued by the knowledge source   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_predicates(async=True)
        >>> result = thread.get()

        :param async bool
        :param list[int] beacons: set of aggregator indices of beacons to constrain predicates returned 
        :return: list[ServerPredicate]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_predicates_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_predicates_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_predicates_with_http_info(self, **kwargs):  # noqa: E501
        """get_predicates  # noqa: E501

        Get a list of predicates used in statements issued by the knowledge source   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_predicates_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param list[int] beacons: set of aggregator indices of beacons to constrain predicates returned 
        :return: list[ServerPredicate]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_predicates" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/predicates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ServerPredicate]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_knowledge_map_statement import ServerKnowledgeMapStatement  # noqa: F401,E501


class ServerKnowledgeMap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beacon': 'int',
        'statements': 'list[ServerKnowledgeMapStatement]'
    }

    attribute_map = {
        'beacon': 'beacon',
        'statements': 'statements'
    }

    def __init__(self, beacon=None, statements=None):  # noqa: E501
        """ServerKnowledgeMap - a model defined in Swagger"""  # noqa: E501

        self._beacon = None
        self._statements = None
        self.discriminator = None

        if beacon is not None:
            self.beacon = beacon
        if statements is not None:
            self.statements = statements

    @property
    def beacon(self):
        """Gets the beacon of this ServerKnowledgeMap.  # noqa: E501

        aggregator assigned beacon index identifier   # noqa: E501

        :return: The beacon of this ServerKnowledgeMap.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerKnowledgeMap.

        aggregator assigned beacon index identifier   # noqa: E501

        :param beacon: The beacon of this ServerKnowledgeMap.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def statements(self):
        """Gets the statements of this ServerKnowledgeMap.  # noqa: E501


        :return: The statements of this ServerKnowledgeMap.  # noqa: E501
        :rtype: list[ServerKnowledgeMapStatement]
        """
        return self._statements

    @statements.setter
    def statements(self, statements):
        """Sets the statements of this ServerKnowledgeMap.


        :param statements: The statements of this ServerKnowledgeMap.  # noqa: E501
        :type: list[ServerKnowledgeMapStatement]
        """

        self._statements = statements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerKnowledgeMap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
